@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014, 2015 (c)
+ *    Copyright 2014, 2015, 2016, 2017, 2018 (c)
  * 
  *    file: defs.h
  *    This file is part of mino.
@@ -18,17 +18,11 @@
  *    You should have received a copy of the GNU General Public License
  *    along with mino.  If not, see <http://www.gnu.org/licenses/>.
  */    
-
-#include <stdio.h>
-#include <errno.h>
-
 #ifndef __Mino_PRO_H
 #define __Mino_PRO_H
 
-#ifndef __BOOL_DEFINED_
-#define __BOOL_DEFINED_
-typedef int bool;
-#endif
+#include <stdio.h>
+#include <errno.h>
 
 int SCREEN_W;
 int SCREEN_H;
@@ -65,31 +59,6 @@ int SCREEN_H;
 #define BGWHITE    47      //set white background
 #define BGDEFAULT  49      //set default background color
 
-//Definitions for keyboard key scancodes//
-//--> use ones defined in kbd.h
-/*#define UP_KEY		1
-#define DOWN_KEY	2
-#define LEFT_KEY	3
-#define RIGHT_KEY	4
-#define HOME_KEY	5
-#define END_KEY		6
-#define ENTER_KEY	7
-#define TAB_KEY		8
-#define BACKSPACE_KEY	9
-#define ESC_KEY		10
-#define SPACE_KEY	32
-#define DEL_KEY		12
-#define ALT_F_KEY	13
-#define ALT_E_KEY	14
-#define ALT_H_KEY	15
-#define CTRL_X_KEY	16
-#define CTRL_V_KEY	17
-#define CTRL_O_KEY	18
-#define CTRL_P_KEY	19
-#define CTRL_F_KEY	20
-#define CTRL_A_KEY	21
-*/
-
 //buttons used in message boxes//
 #define OK	1	//00000001
 #define YES	2	//00000010
@@ -100,55 +69,60 @@ int SCREEN_H;
 //types of message displayed in message boxes//
 typedef enum msgT { INFO, ERROR, CONFIRM } msgType;
 
-#define MAXDIRS		255
-#define	MAXFILES	255
+#define MAXDIRS		1024
+#define	MAXFILES	1024
 //int MAXDIRS;
 //int MAXFILES;
 int MAX_DIR_NAME_LEN;
-int MAX_FILE_NAME_LEN;
+//int MAX_FILE_NAME_LEN;
+#define MAX_FILE_NAME_LEN   1024
 int MAX_MSG_BOX_W;
 int MAX_MSG_BOX_H;
 #define MAX_INPUT_MSG_LEN 100
 
 //Function prototypes//
 //clearArea is a flag to indicate whether to clear the window with spaces
-void drawBox(int x1, int y1, int x2, int y2, char *title, int clearArea);   
+void drawBox(int x1, int y1, int x2, int y2, char* title, int clearArea, int isMainWindow);   
 void drawMenuBar(int x, int y, int w);
 void setScreenColors(int FG, int BG);
+void setScreenColorsI(int colorIndex);
 void getScreenSize();
 void clearScreen();
-void init();
+void showCursor();
+void hideCursor();
+void init(char *open_file_name);
+int  initNewDocument();
+int __initNewDocument();
+void resetLineCounters();
 void init_built_in_defaults();
 void init_error();
-void exit_gracefully(int exit_code);
+void exit_gracefully(int exit_code, char *open_file_name);
 void parseLineArgs(int argc, char **argv);
-int scanDir(char *dir);
+int scanDir(char *dir, char ***dirs, char ***files, int *totalDirs, int *totalFiles);
 
 int msgBox(char *msg, int Buttons, msgType tmsg);
-char* inputBox(char *msg, char *title);
+char *inputBox(char *msg, char *title);
+char *getUserInput(char *msg, char *title);
 char input[(MAX_INPUT_MSG_LEN*4)+1];//input string returned by inputBox() function
 
 void refreshDirView();
 void refreshView();
+void refreshViewLines(int start, int end, int startOutputAt);
 void refreshSelectedLine();
-void refreshSelectedLineInColor(int pos);
+void refreshSelectedLineInColor(int pos, int *incomment);
 void refreshBottomView();
-void showFileMenu(int visible);
-void showEditMenu(int visible);
-void showOptionsMenu(int visible);
-void showHelpMenu(int visible);
-void showReadMe();	//called from help menu to show README file
-void showKeybindings();	//called from help menu to show KEYBINDINGS file
 
 //openSave determines if the function is to open or save a file
 //showDialog: if YES, show open dialogbox, if NO, don't
 //The function returns 1 if successful, 0 if failed to open/save file
 typedef enum opensaveE { OPEN, SAVE } OPEN_SAVE;
-int openSaveFile(OPEN_SAVE openSave, int showDialog);
-
-int _openFile();//called by above function to actually do the work of opening file
-int _saveFile();//called by above function to actually do the work of saving file
-bool NEW_FILE;	//boolean telling if the current file is a new or opened one
+char *openSaveFile(OPEN_SAVE openSave, int showDialog, char *open_file_name);
+//called by above function to actually do the work of opening file
+int _openFile(char *open_file_name);
+//called by above function to actually do the work of saving file
+int _saveFile(char *open_file_name);
+void checkFileExtension(char *open_file_name);
+int NEW_FILE;	//boolean telling if the current file is a new or opened one
 
 //Menu items//
 char *menu[4];
@@ -161,12 +135,9 @@ char *fileMenu[6];
 char *editMenu[10];
 char *optionsMenu[4];
 char *helpMenu[4];
+void showMenu(int index, char *open_file_name);
 
 int x, y, w, h;
-char *dirs[MAXDIRS];
-char *files[MAXFILES];
-int numVisDirs, firstVisDir, selectedDir, totalDirs;
-int numVisFiles, firstVisFile, selectedFile, totalFiles;
 
 //values used in the activeWindow variable//
 #define DIR_WIN		1
@@ -179,25 +150,37 @@ void catchSignals();
 
 char *cwd;	//the current working directory
 char *config_file_name;//string holding the name of the config file
-char *open_file_name;
 FILE *config_file;
-FILE *open_file;
-bool open_file_at_startup;
+int  open_file_at_startup;
 
 #define MAX_LINES	5000
-char *lines[MAX_LINES];
+struct linestruct
+{
+    char *text;
+    int  byteCount;
+    int  charCount;
+    int  linkedToNext;
+    int  bytesAlloced;
+} linestruct;
+extern struct linestruct *lines[MAX_LINES];
+
+struct linestruct *allocLineStruct();
+struct linestruct *allocLineStructB(int bytes);
+void copyLineStruct(int pos1, int pos2);
+void freeLineStruct(struct linestruct *line);
+
 int MAX_CHARS_PER_LINE;
+int maxLen;
 int firstVisLine;
 int totalVisLines;
 int totalLines;
-int totalCharsInLine[MAX_LINES];
-bool LINE_IS_LINKED[MAX_LINES];
 int selectedLine;
 int selectedChar;
 int selectedCharCarry;
-bool WRAP_LINES;//if TRUE (1), lines are wrapped, ie will not go on beyond screen limits
+int WRAP_LINES;//if TRUE (1), lines are wrapped, ie will not go on beyond screen limits
 int TAB_CHARS;	//number of spaces in a TAB
 char *documentTitle;//[MAX_FILE_NAME_LEN];	//document title is the file name
+#define __DEFAULT_TITLE   "untitled"
 char *DEFAULT_TITLE;
 void insertChar(char *ch);
 void insertTab();
@@ -207,23 +190,42 @@ void deleteNextChar();
 void deletePrevWord();
 void deleteNextWord();
 void deleteLine();
+int  charsToBytes(int pos, int selChar);
+void postDeleteWord(int pos);
+int appendToLine(int posTo, int posFrom, int count);
+void checkLineBounds(int pos);
+void copyInLine(int pos, int to, int from, int calcTotalChars);
+int extendLineText(int pos, int newSize);
+
 //enumeration determining the state of the open file
 enum fstate { MODIFIED, NEW, SAVED, OPENED, IDLE } FILE_STATE;
 //whether to show README file on startup
-bool SHOW_README;
+extern int  SHOW_README;
 void showREADMEOnStartup();
 
 void sighandler(int signo);
 
 //print unicode char at line 'pos' with index of 'index'
 //into the screen
-void putuchar(int pos, int index);
+void putuchar(int pos, int index, int *carry);
 void putunichar(char *ch);
 int GNU_DOS_LEVEL;
 int makestr(char *newstr, char *str);
 void move_lines_up(int first, int last);
+void move_lines_upd(int first, int diff);
 void move_lines_down(int first, int last);
+void move_lines_downl(int first, int last, char *newLineText);
 void calcCharCarry(int pos);
-bool is_whitespace(char c);
+int  is_whitespace(char c);
+
+extern char *strdup(const char *s);    /* string.h */
+extern int fcloseall (void);    /* stdio.h */
+extern char *strcasestr (const char *HAYSTACK, const char *NEEDLE);    /* string.h */
+extern int strcasecmp (const char *S1, const char *S2);     /* string.h */
+extern char *copyrightNotice;
+
+void initDirView();
+
+#define TABSPACES(index)        (TAB_CHARS-((TAB_CHARS+(index))%TAB_CHARS))
 
 #endif
