@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014, 2015, 2016 (c)
+ *    Copyright 2014, 2015, 2016, 2017, 2018 (c)
  * 
  *    file: kbd.c
  *    This file is part of mino.
@@ -37,23 +37,16 @@ static int old_keyboard_mode;
 int initTerminal()
 {
     struct termios tty_attr;
-
-    /* save old keyboard mode */
-    if (ioctl(0, KDGKBMODE, &old_keyboard_mode) < 0) 
-    {
-	X_IS_RUNNING = 1;
-    } else X_IS_RUNNING = 0;
-
     tcgetattr(0, &tty_attr_old);
-
     /* turn off buffering, echo and key processing */
-    tty_attr          = tty_attr_old;
-    tty_attr.c_lflag &= ~(ICANON | ECHO | ISIG);
-    tty_attr.c_iflag &= ~(ISTRIP | INLCR | ICRNL | IGNCR | IXON | IXOFF);
-    if((tcsetattr(0, TCSANOW, &tty_attr) == -1)) return 0;
-
-    if(!X_IS_RUNNING) ioctl(0, KDSKBMODE, K_RAW);
-    //ioctl(0, KDSKBMODE, K_UNICODE);
+    tty_attr.c_iflag &= ~(IGNBRK | BRKINT | PARMRK | ISTRIP | INLCR | IGNCR | ICRNL | IXON);
+    tty_attr.c_oflag &= ~OPOST;
+    tty_attr.c_lflag &= ~(ECHO | ECHONL | ICANON | ISIG | IEXTEN);
+    tty_attr.c_cflag &= ~(CSIZE | PARENB);
+    tty_attr.c_cflag |= CS8;
+    tty_attr.c_cc[VMIN] = 1;          /* wait until at least one keystroke available */
+    tty_attr.c_cc[VTIME] = 0;         /* no timeout */
+    if((tcsetattr(0, TCSAFLUSH, &tty_attr) == -1)) return 0;
     ALT   = 0; 
     CTRL  = 0; 
     SHIFT = 0;
@@ -62,16 +55,8 @@ int initTerminal()
 
 void restoreTerminal()
 {
-    if(X_IS_RUNNING) 
-    {
-	    tcsetattr(0, TCSANOW, &tty_attr_old);
-    }
-    else
-    {
-	    tcsetattr(0, TCSAFLUSH, &tty_attr_old);
-	    ioctl(0, KDSKBMODE, old_keyboard_mode);
-    }
-}//end restoreTerminal()
+    tcsetattr(0, TCSAFLUSH, &tty_attr_old);
+}
 
 char *getKeyUnderConsole()
 {
@@ -338,10 +323,172 @@ char *getKeyUnderX()
 }
 
 
-
+/*
+ * SEE: http://www.comptechdoc.org/os/linux/howlinuxworks/linux_hlkeycodes.html
+ */
 char *getKey()
 {
-	if(X_IS_RUNNING) return getKeyUnderX();
-	else return getKeyUnderConsole();
-}
+    //if(X_IS_RUNNING) return getKeyUnderX();
+    //else return getKeyUnderConsole();
+    
+    int bytes = 0;
+    int esc = 0;
+    int c = getchar();
+    char *ch = uc;
+    int extra;
+    ALT = 0; CTRL = 0; SHIFT = 0;
 
+    // check for UTF-8 multibyte characters
+    if ((c & mask[0]) == mask[0]) bytes++;
+    if ((c & mask[1]) == mask[1]) bytes++;
+    if ((c & mask[2]) == mask[2]) bytes++;
+    if(bytes)
+    {
+        *ch++ = c;
+        while(bytes--)
+        {
+            c = getchar();
+            *ch++ = c;
+        }
+        return uc;
+    }
+
+    // check for possible escape sequences
+    if(c == 0x1b)
+    {
+        esc = 1;
+        c = getchar();
+    }
+    
+switchkey:
+    
+    switch(c)
+    {
+        case 0x07:
+        case 0x08:
+        case 0x09:
+        case 0x0a:
+        case 0x0b:
+        case 0x0c:
+        case 0x0d:
+        case 0x1b:
+            break;
+        case 0x5b:
+            c = getchar();
+            extra = 1;
+            switch(c)
+            {
+                case 0x31:
+                    c = getchar();
+                    switch(c)
+                    {
+                        case 0x3b:
+                            CTRL = 1;
+                            c = getchar();
+                            c = 0x5b;
+                            goto switchkey;
+                        case 0x7e: c = HOME_KEY; break;
+                        /*
+                         * TODO: handle function keys here. See the link above.
+                         */
+                        default:   c = '['; break;
+                    }
+                    break;
+                case 0x32:
+                    c = getchar();
+                    switch(c)
+                    {
+                        case 0x7e: c = INS_KEY; break;
+                        /* ditto ... */
+                        default:   c = '['; break;
+                    }
+                    break;
+                case 0x33:
+                    c = getchar();
+                    switch(c)
+                    {
+                        /* ditto ... */
+                        default:   c = '['; break;
+                    }
+                    break;
+                case 0x34:
+                    c = END_KEY;
+                    break;
+                case 0x35:
+                    c = PGUP_KEY;
+                    break;
+                case 0x36:
+                    c = PGDOWN_KEY;
+                    break;
+                case 0x41:
+                    c = UP_KEY;
+                    extra = 0;
+                    break;
+                case 0x42:
+                    c = DOWN_KEY;
+                    extra = 0;
+                    break;
+                case 0x43:
+                    c = RIGHT_KEY;
+                    extra = 0;
+                    break;
+                case 0x44:
+                    c = LEFT_KEY;
+                    extra = 0;
+                    break;
+                case 0x46:
+                    c = END_KEY;
+                    extra = 0;
+                    break;
+                case 0x47:
+                    c = '5';
+                    extra = 0;
+                    break;
+                case 0x48:
+                    c = HOME_KEY;
+                    extra = 0;
+                    break;
+                case 0x50:
+                        /*
+                         * TODO: this should be the Pause key.
+                         */
+                    c = '[';
+                    extra = 0;
+                    break;
+                case 0x5b:
+                    c = getchar();
+                    /*
+                     * TODO: handle function keys here. See the link above.
+                     */
+                    c = '[';
+                    extra = 0;
+                    break;
+                default:
+                    //printf("c = %d [%c]", c, c);
+                    break;
+            }
+            if(extra)
+            {
+                while(getchar() != 0x7e) ;
+            }
+            esc = 0;
+            break;
+        case 0x7f:
+            c = '\b';
+            break;
+        default:
+            if(c < 0x20)
+            {
+                CTRL = 1;
+                c += 0x40;
+            }
+            //printf("c = %d [%c]", c, c);
+            break;
+    }
+
+    *ch++ = c;
+    *ch   = '\0';
+    if(esc) ALT = 1;
+    //printf("c = %d [%c]", c, c);
+    return uc;
+}
