@@ -1,22 +1,22 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014, 2015 (c)
+ *    Copyright 2014, 2015, 2016, 2017, 2018 (c)
  * 
  *    file: msgbox.c
- *    This file is part of mino (Mino).
+ *    This file is part of mino.
  *
- *    mino (Mino) is free software: you can redistribute it and/or modify
+ *    mino is free software: you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
  *    the Free Software Foundation, either version 3 of the License, or
  *    (at your option) any later version.
  *
- *    mino (Mino) is distributed in the hope that it will be useful,
+ *    mino is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *    GNU General Public License for more details.
  *
  *    You should have received a copy of the GNU General Public License
- *    along with mino (Mino).  If not, see <http://www.gnu.org/licenses/>.
+ *    along with mino.  If not, see <http://www.gnu.org/licenses/>.
  */    
 
 #include <string.h>
@@ -25,6 +25,7 @@
 #include "defs.h"
 #include "kbd.h"
 #include "options.h"
+#include "edit.h"
 
 /* how long is the input? */
 int inputLen = 0;
@@ -35,14 +36,14 @@ int firstVisChar = 0;
 
 void putunichar(char *ch)
 {
-  static char c[5];
-  memset(c, 0, 5);
-  c[0] = ch[0];
-  if ((c[0] & mask[0]) == mask[0]) c[1] = ch[1];
-  if ((c[0] & mask[1]) == mask[1]) c[2] = ch[2];
-  if ((c[0] & mask[2]) == mask[2]) c[3] = ch[3];
-  c[4] = '0';
-  printf("%s", c);
+    static char c[5];
+    memset(c, 0, 5);
+    c[0] = ch[0];
+    if ((c[0] & mask[0]) == mask[0]) c[1] = ch[1];
+    if ((c[0] & mask[1]) == mask[1]) c[2] = ch[2];
+    if ((c[0] & mask[2]) == mask[2]) c[3] = ch[3];
+    c[4] = '0';
+    fprintf(stdout, "%s", c);
 }
 
 /**************************************************************************
@@ -52,13 +53,13 @@ void putunichar(char *ch)
  * msgType). It returns the input string if the user presses OK, or a NULL 
  * pointer if he pressed Cancel or entered an empty string.
  * ************************************************************************/
-char* inputBox(char *msg, char *title) 
+char *inputBox(char *msg, char *title) 
 {
   int msgW = 0;
   int msgH = 0;
   int j, i = 0;
 
-  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+  setScreenColorsI(COLOR_WINDOW);
   j = 0;
   for(i = 0; i < strlen(msg); i++) 
   {
@@ -82,7 +83,7 @@ char* inputBox(char *msg, char *title)
   drawBox( x,
 	   y,
 	  (SCREEN_H/2)+(msgH/2),
-	  (SCREEN_W/2)+(msgW/2), title, YES);
+	  (SCREEN_W/2)+(msgW/2), title, YES, 0);
   
   y+=2; j=x+1; x++;
   int l=y;
@@ -104,7 +105,7 @@ char* inputBox(char *msg, char *title)
   }
 
  /* put an empty field for user entry */
- setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
+ setScreenColorsI(COLOR_HIGHLIGHT_TEXT);
  fprintf(stdout, "\e[%d;%dH", x+(msgH-4), y);
  for(i = 0; i < msgW-3; i++) putchar(' ');
  
@@ -116,7 +117,7 @@ char* inputBox(char *msg, char *title)
  
  bx = x + (msgH-2);
  by = y + ((msgW-16)/2) - 2;
- setScreenColors(FG_COLOR[COLOR_BUTTONS], BG_COLOR[COLOR_BUTTONS]);
+ setScreenColorsI(COLOR_BUTTONS);
  fprintf(stdout, "\x1b[%d;%dH", bx, by);
  fprintf(stdout, "   OK   ");
  by += 12;
@@ -127,7 +128,6 @@ char* inputBox(char *msg, char *title)
  fflush(stdout);
  //wait for user response//
  char *ch;
- ch = (char *)malloc(5);
  
  while(1) 
  {	//infinite program loop//
@@ -207,13 +207,11 @@ do_left:
 	  by = y + ((msgW-16)/2) - 2;
 	  if(sel == 0) 
 	  {
-	    setScreenColors(FG_COLOR[COLOR_BUTTONS], BG_COLOR[COLOR_BUTTONS]);
-	    //setScreenColors(WHITE, BGRED);
+	    setScreenColorsI(COLOR_BUTTONS);
 	    fprintf(stdout, "\x1b[%d;%dH", bx, by);
 	    fprintf(stdout, "   OK   ");
 	    by += 12;
-	    setScreenColors(FG_COLOR[COLOR_HBUTTONS], BG_COLOR[COLOR_HBUTTONS]);
-	    //setScreenColors(GREEN, BGRED);
+	    setScreenColorsI(COLOR_HBUTTONS);
 	    fprintf(stdout, "\x1b[%d;%dH", bx, by);
 	    fprintf(stdout, " CANCEL ");
 	    sel = 1;
@@ -221,8 +219,7 @@ do_left:
 	  } 
 	  else if(sel == 1) 
 	  {
-	    setScreenColors(FG_COLOR[COLOR_BUTTONS], BG_COLOR[COLOR_BUTTONS]);
-	    //setScreenColors(WHITE, BGRED);
+	    setScreenColorsI(COLOR_BUTTONS);
 	    fprintf(stdout, "\x1b[%d;%dH", bx, by);
 	    fprintf(stdout, "   OK   ");
 	    by += 12;
@@ -233,13 +230,11 @@ do_left:
 	  } 
 	  else 
 	  {
-	    setScreenColors(FG_COLOR[COLOR_HBUTTONS], BG_COLOR[COLOR_HBUTTONS]);
-	    //setScreenColors(GREEN, BGRED);
+	    setScreenColorsI(COLOR_HBUTTONS);
 	    fprintf(stdout, "\x1b[%d;%dH", bx, by);
 	    fprintf(stdout, "   OK   ");
 	    by += 12;
-	    setScreenColors(FG_COLOR[COLOR_BUTTONS], BG_COLOR[COLOR_BUTTONS]);
-	    //setScreenColors(WHITE, BGRED);
+	    setScreenColorsI(COLOR_BUTTONS);
 	    fprintf(stdout, "\x1b[%d;%dH", bx, by);
 	    fprintf(stdout, " CANCEL ");
 	    sel = 0;
@@ -262,7 +257,7 @@ do_del:
 	  input[i*4+3] = input[i*4+7];
 	}
 	input[(--inputLen)*4] = '\0';
-	setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
+	setScreenColorsI(COLOR_HIGHLIGHT_TEXT);
 	fprintf(stdout, "\x1b[%d;%dH", bx-2, y+highlightChar);	//adjust cursor to point at input field
 	for(i = highlightChar; i < (msgW-3); i++) 
 	{
@@ -300,7 +295,7 @@ do_del:
 	  }
 	  input[(--inputLen)*4] = '\0';
 	}//end else
-	setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
+	setScreenColorsI(COLOR_HIGHLIGHT_TEXT);
 	fprintf(stdout, "\x1b[%d;%dH", bx-2, y);	//adjust cursor to point at input field
 	for(i = firstVisChar; i < (firstVisChar+msgW-3); i++) 
 	{
@@ -310,16 +305,13 @@ do_del:
 	fprintf(stdout, "\x1b[%d;%dH", bx-2, y+highlightChar);	//adjust cursor to point at input field
 	fflush(stdout); break;
       default:
-	  //if((ch >= 'a' && ch <= 'z') || (ch >= 'A' && ch <= 'Z')  ||
-	  //   (ch >= 32 && ch<= 64) || (ch >=123 && ch <= 126)) {//if it is alphanumeric
 enterInputChar:
 	    if(strlen(input)/4 >= MAX_INPUT_MSG_LEN) break;
-	    setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
+            setScreenColorsI(COLOR_HIGHLIGHT_TEXT);
 	    //inserting in the middle of a string means we need to shift all chars one position
 	    //to the right before inserting the new char at the highlighted position.
 	    if(input[highlightChar*4] != '\0') 
 	    {
-	      //for(i = inputLen; i > firstVisChar+highlightChar; i--) input[i] = input[i-1];
 	      for(i = inputLen; i > firstVisChar+highlightChar; i--)
 	      {
 		input[i*4] = input[i*4-4];
@@ -363,18 +355,13 @@ enterInputChar:
 		}
 	      }
 	      fprintf(stdout, "\x1b[%d;%dH", bx-2, y+highlightChar);	//adjust cursor to point at input field
-	      //fprintf(stdout, "\x1b[%d;%dH", bx-2, y+2);	//adjust cursor to point at input field
 	    }
-	  //}
 	  fflush(stdout); 
     }
  }
-  //do {;} while (!getchar());
 
-  //free(tmpC);
-  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
-  //setScreenColors(WHITE, BGBLUE);
-  return NULL;
+ setScreenColorsI(COLOR_WINDOW);
+ return NULL;
 }
 
 
@@ -394,14 +381,13 @@ int msgBox(char *msg, int Buttons, msgType tmsg)
   char *title;
   switch(tmsg) 
   {
-    case(INFO): title = " INFORMATION "; break;
-    case(ERROR): title = " ERROR "; break;
+    case(INFO)   : title = " INFORMATION " ; break;
+    case(ERROR)  : title = " ERROR "       ; break;
     case(CONFIRM): title = " CONFIRMATION "; break;
-    default: title = " MESSAGE "; break;
+    default      : title = " MESSAGE "     ; break;
   }
 
-  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
-  //setScreenColors(WHITE, BGBLUE);
+  setScreenColorsI(COLOR_WINDOW);
   j = 0;
   for(i = 0; i < strlen(msg); i++) 
   {
@@ -418,7 +404,6 @@ int msgBox(char *msg, int Buttons, msgType tmsg)
   }
   msgH += 5;
   msgW += 3;	//adjust box size
-  //msgW = MAX_MSG_BOX_W;
   //draw the empty window first//
   int x, y;
   x = (SCREEN_H/2)-(msgH/2);
@@ -426,7 +411,7 @@ int msgBox(char *msg, int Buttons, msgType tmsg)
   drawBox( x,
 	   y,
 	  (SCREEN_H/2)+(msgH/2),
-	  (SCREEN_W/2)+(msgW/2), title, YES);
+	  (SCREEN_W/2)+(msgW/2), title, YES, 0);
   
   y+=2; j=x+1; x++;
   int l=y;
@@ -454,13 +439,11 @@ int msgBox(char *msg, int Buttons, msgType tmsg)
   {	// OK/CANCEL combination
     bx = x + (msgH-3);
     by = y + ((msgW-16)/2) - 2;
-    setScreenColors(FG_COLOR[COLOR_HBUTTONS], BG_COLOR[COLOR_HBUTTONS]);
-    //setScreenColors(GREEN, BGRED);
+    setScreenColorsI(COLOR_HBUTTONS);
     fprintf(stdout, "\x1b[%d;%dH", bx, by);
     fprintf(stdout, "   OK   ");
     by += 12;
-    setScreenColors(FG_COLOR[COLOR_BUTTONS], BG_COLOR[COLOR_BUTTONS]);
-    //setScreenColors(WHITE, BGRED);
+    setScreenColorsI(COLOR_BUTTONS);
     fprintf(stdout, "\x1b[%d;%dH", bx, by);
     fprintf(stdout, " CANCEL ");
     fprintf(stdout, "\x1b[%d;%dH", bx, by-9);	//adjust cursor to point at "OK"
@@ -469,13 +452,11 @@ int msgBox(char *msg, int Buttons, msgType tmsg)
   {	// YES/NO combination
     bx = x + (msgH-3);
     by = y + ((msgW-16)/2) - 2;
-    setScreenColors(FG_COLOR[COLOR_HBUTTONS], BG_COLOR[COLOR_HBUTTONS]);
-    //setScreenColors(GREEN, BGRED);
+    setScreenColorsI(COLOR_HBUTTONS);
     fprintf(stdout, "\x1b[%d;%dH", bx, by);
     fprintf(stdout, "   YES  ");
     by += 12;
-    setScreenColors(FG_COLOR[COLOR_BUTTONS], BG_COLOR[COLOR_BUTTONS]);
-    //setScreenColors(WHITE, BGRED);
+    setScreenColorsI(COLOR_BUTTONS);
     fprintf(stdout, "\x1b[%d;%dH", bx, by);
     fprintf(stdout, "   NO   ");
     fprintf(stdout, "\x1b[%d;%dH", bx, by-9);	//adjust cursor to point at "YES"
@@ -484,8 +465,7 @@ int msgBox(char *msg, int Buttons, msgType tmsg)
   {			// OK only
     bx = x + (msgH-3);
     by = y + ((msgW-8)/2) - 2;
-    setScreenColors(FG_COLOR[COLOR_HBUTTONS], BG_COLOR[COLOR_HBUTTONS]);
-    //setScreenColors(GREEN, BGRED);
+    setScreenColorsI(COLOR_HBUTTONS);
     fprintf(stdout, "\x1b[%d;%dH", bx, by);
     fprintf(stdout, "   OK   ");
     fprintf(stdout, "\x1b[%d;%dH", bx, by+3);	//adjust cursor to point at "OK"
@@ -494,7 +474,6 @@ int msgBox(char *msg, int Buttons, msgType tmsg)
  fflush(stdout); 
  //wait for user response//
  char *ch;
- ch = (char *)malloc(5);
  
  while(1) 
  {	//infinite program loop//
@@ -586,10 +565,29 @@ do_tab:
 	fflush(stdout); break;
     }
  }
-  //do {;} while (!getchar());
 
-  //free(tmpC);
   setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
-  //setScreenColors(WHITE, BGBLUE);
   return(0);
 }
+
+
+char *getUserInput(char *msg, char *title)
+{
+    inputBox(msg, title);
+    int len1 = strlen(input);
+    if(!len1) return NULL;
+    char *res = (char *)malloc(len1+1);
+    if(!res) return NULL;
+    char *f = res, *i = input;
+    char *iend = i+len1;
+    while(i < iend)
+    {
+        *f++ = *i;
+        if ((*++i & mask[0]) == mask[0]) *f++ = *i;
+        if ((*++i & mask[1]) == mask[1]) *f++ = *i;
+        if ((*++i & mask[2]) == mask[2]) *f++ = *i;
+        i++;
+    }
+    *f = '\0';
+    return res;
+}
