@@ -1,22 +1,22 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014 (c)
+ *    Copyright 2014, 2015, 2016, 2017, 2018 (c)
  * 
  *    file: options.h
- *    This file is part of mino (Mino).
+ *    This file is part of mino.
  *
- *    mino (Mino) is free software: you can redistribute it and/or modify
+ *    mino is free software: you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
  *    the Free Software Foundation, either version 3 of the License, or
  *    (at your option) any later version.
  *
- *    mino (Mino) is distributed in the hope that it will be useful,
+ *    mino is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *    GNU General Public License for more details.
  *
  *    You should have received a copy of the GNU General Public License
- *    along with mino (Mino).  If not, see <http://www.gnu.org/licenses/>.
+ *    along with mino.  If not, see <http://www.gnu.org/licenses/>.
  */    
 #ifndef __OPTIONS_H
 #define __OPTIONS_H
@@ -26,6 +26,7 @@
 void optionsMenu_Change_Colors();
 void optionsMenu_Tab_Spaces();
 void optionsMenu_Reset_Config();
+void optionsMenu_Autoindent();
 
 #define changeColorsDialogOptionsN	6
 
@@ -45,12 +46,13 @@ int BG_COLOR_ARRAY[8];
 char *findColorName(int c);
 void refreshChangeColorsDialog();
 void write_config_file();
+void _write_config_file(FILE *file, int write_defaults);
 void saveOldColors();
 void resetColors();
 int showColorChooserDialog();
 
 //determine if automatic highlighting is on/off
-bool AUTO_HIGHLIGHTING;
+int AUTO_HIGHLIGHTING;
 //different highlight modes according to opened file
 typedef enum 
 {
@@ -70,7 +72,7 @@ typedef enum
 } hmode;
 hmode HIGHLIGHT_MODE;
 //special colors for syntax highlighting
-#define COLOR_HCOMMENT		37
+#define COLOR_HCOMMENT		36
 #define COLOR_HKEYWORD		33
 #define COLOR_HSTRING		31
 #define COLOR_HDIRECTIVE	35
@@ -78,13 +80,10 @@ hmode HIGHLIGHT_MODE;
 #define COLOR_HBRACES		32
 #define COLOR_HWINDOW		40
 int old_window_color;
-char *keyword[420];
-int total_keywords;
-void loadKeywords(hmode mode);
 
 //switch auto-indentation on/off
-bool AUTO_INDENT;
+int  AUTO_INDENT;
 //the string holding the spaces/tabes to indent new lines
-char AUTO_INDENT_STR[100];
+char *autoIndentStr;
 
-#endif
\ No newline at end of file
+#endif
