@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014, 2015 (c)
+ *    Copyright 2014, 2015, 2016, 2017, 2018 (c)
  * 
  *    file: options.c
  *    This file is part of Prime.
@@ -20,7 +20,7 @@
  */    
 #include "defs.h"
 #include "options.h"
-#include "../corelib/kbd.h"
+#include kbd_header
 #include <pwd.h>
 #include <string.h>
 #include <unistd.h>
@@ -106,7 +106,7 @@ int showColorChooserDialog()
       case(UP_KEY):
 	if(GNU_DOS_LEVEL > 1) break;
 do_up:
-	//msgBox("UP", OK, INFO);
+	//msgBoxH("UP", OK, INFO);
 	if(i <= 30) 
 	{
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
@@ -142,7 +142,7 @@ do_up:
       case(DOWN_KEY):
 	if(GNU_DOS_LEVEL > 1) break;
 do_down:
-	//msgBox("DOWN", OK, INFO);
+	//msgBoxH("DOWN", OK, INFO);
 	if(i >= 38) 
 	{
 	  setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
@@ -174,7 +174,7 @@ do_down:
 	break;
       case(ENTER_KEY):
       case(SPACE_KEY):
-	//msgBox("ENTER", OK, INFO);
+	//msgBoxH("ENTER", OK, INFO);
 	//c = getKey();
 	if(i == 38) { i = 0; return 0; break; }
 	endme = 1; //fflush(stdin);
@@ -189,7 +189,7 @@ do_down:
       default:
 	if(GNU_DOS_LEVEL > 2) break;
 do_esc:
-	//msgBox("DEFAULT", OK, INFO);
+	//msgBoxH("DEFAULT", OK, INFO);
 	endme = 1; //i = 0; //fflush(stdin);
 	return 0; break;
     }//end switch
@@ -334,9 +334,9 @@ do_esc:
 	    if(tmp) FG_COLOR[sel] = tmp;
 	    //else { sprintf(lines[0], "%d", tmp); return; }
 	    //c = DOWN_KEY;
-	    //msgBox("1", OK, INFO);
+	    //msgBoxH("1", OK, INFO);
 	    refreshChangeColorsDialog();
-	    //msgBox("2", OK, INFO);
+	    //msgBoxH("2", OK, INFO);
 	    //if(!X_IS_RUNNING) c = getKey();
 	    break;
 	  } 
@@ -354,7 +354,7 @@ do_esc:
 	break;
     }//end switch
     //printf("%d..%c", c, c);
-    //msgBox("3", OK, INFO);
+    //msgBoxH("3", OK, INFO);
     //refreshChangeColorsDialog();
     //printf("         ..%c,%d", c, c);
   }//end while
@@ -369,7 +369,7 @@ void optionsMenu_Reset_Config()
 {
       if(!(pass = getpwuid(geteuid()))) 
       {
-	msgBox("Couldn't open home directory to write config file.", OK, ERROR);
+	msgBoxH("Couldn't open home directory to write config file.", OK, ERROR);
 	refreshFileView();
 	refreshDirView();
 	return;
@@ -377,7 +377,7 @@ void optionsMenu_Reset_Config()
       config_file_name = (char *) malloc(strlen(pass->pw_dir)+12);
       if(!config_file_name)
       {
-	msgBox("Insufficient memory", OK, ERROR);
+	msgBoxH("Insufficient memory", OK, ERROR);
 	refreshFileView();
 	refreshDirView();
 	return;
@@ -387,7 +387,7 @@ void optionsMenu_Reset_Config()
       strcat(config_file_name, ".prime.conf");
       if(!(config_file = fopen(config_file_name, "w"))) 
       {
-	msgBox("Couldn't write to config file in home directory.", OK, ERROR);
+	msgBoxH("Couldn't write to config file in home directory.", OK, ERROR);
 	refreshFileView();
 	refreshDirView();
 	return;
@@ -410,7 +410,7 @@ void optionsMenu_Reset_Config()
       fprintf(config_file, "#GnuDOS Level\n");
       fprintf(config_file, "GNU_DOS_LEVEL = 1\n");
       fclose(config_file);
-      msgBox("Finished writing default values to ~/.prime.conf", OK, INFO);
+      msgBoxH("Finished writing default values to ~/.prime.conf", OK, INFO);
       free(config_file_name);
       refreshFileView();
       refreshDirView();
@@ -421,7 +421,7 @@ void write_config_file()
 {
       if(!(pass = getpwuid(geteuid()))) 
       {
-	msgBox("Couldn't open home directory to write config file.", OK, ERROR);
+	msgBoxH("Couldn't open home directory to write config file.", OK, ERROR);
 	refreshFileView();
 	refreshDirView();
 	return;
@@ -429,7 +429,7 @@ void write_config_file()
       config_file_name = (char *) malloc(strlen(pass->pw_dir)+12);
       if(!config_file_name)
       {
-	msgBox("Insufficient memory", OK, ERROR);
+	msgBoxH("Insufficient memory", OK, ERROR);
 	refreshFileView();
 	refreshDirView();
 	return;
@@ -439,7 +439,7 @@ void write_config_file()
       strcat(config_file_name, ".prime.conf");
       if(!(config_file = fopen(config_file_name, "w"))) 
       {
-	msgBox("Couldn't write to config file in home directory.", OK, ERROR);
+	msgBoxH("Couldn't write to config file in home directory.", OK, ERROR);
 	refreshFileView();
 	refreshDirView();
 	return;
@@ -462,9 +462,16 @@ void write_config_file()
       fprintf(config_file, "#GnuDOS Level\n");
       fprintf(config_file, "GNU_DOS_LEVEL = %d\n", GNU_DOS_LEVEL);
       fclose(config_file);
-      //msgBox("Finished writing default values to ~/.mino.conf", OK, INFO);
+      //msgBoxH("Finished writing default values to ~/.mino.conf", OK, INFO);
       free(config_file_name);
       refreshFileView();
       refreshDirView();
       return;    
 }
+
+void optionsMenu_Properties()
+{
+    showPropertiesDialog();
+    setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+    scanDir(cwd);
+}
